@@ -16,7 +16,7 @@ package PDF::API2::Basic::PDF::File;
 
 use strict;
 
-our $VERSION = '2.029'; # VERSION
+our $VERSION = '2.030_001'; # TRIAL VERSION
 
 =head1 NAME
 
@@ -157,6 +157,7 @@ $cr = '\s*(?:\015|\012|(?:\015\012))';
 
 my $readDebug = 0;
 
+use Carp;
 use IO::File;
 
 # Now for the basic PDF types
@@ -645,21 +646,21 @@ sub readval {
     }
 
     # Boolean
-    elsif ($str =~ m/^(true|false)$irreg_char/) {
+    elsif ($str =~ m/^(true|false)($irreg_char|$)/) {
         $value = $1;
         $str =~ s/^(?:true|false)//;
         $result = PDF::API2::Basic::PDF::Bool->from_pdf($value);
     }
 
     # Number
-    elsif ($str =~ m/^([+-.0-9]+)$irreg_char/) {
+    elsif ($str =~ m/^([+-.0-9]+)($irreg_char|$)/) {
         $value = $1;
         $str =~ s/^([+-.0-9]+)//;
         $result = PDF::API2::Basic::PDF::Number->from_pdf($value);
     }
 
     # Null
-    elsif ($str =~ m/^null$irreg_char/) {
+    elsif ($str =~ m/^null($irreg_char|$)/) {
         $str =~ s/^null//;
         $result = PDF::API2::Basic::PDF::Null->new;
     }
@@ -697,35 +698,68 @@ Returns a fully read object of given number and generation in this file
 
 sub read_objnum {
     my ($self, $num, $gen, %opts) = @_;
+    croak 'Undefined object number in call to read_objnum($num, $gen)' unless defined $num;
+    croak 'Undefined object generation in call to read_objnum($num, $gen)' unless defined $gen;
+    croak "Invalid object number '$num' in call to read_objnum" unless $num =~ /^[0-9]+$/;
+    croak "Invalid object generation '$gen' in call to read_objnum" unless $gen =~ /^[0-9]+$/;
 
     my $object_location = $self->locate_obj($num, $gen) || return;
     my $object;
 
-    if (ref $object_location)
-    {
-        # Compressed object.
-        my $src = $self->read_objnum($object_location->[0], 0, %opts);
-        die 'Cannot find the compressed object stream' unless $src;
+    # Compressed object
+    if (ref($object_location)) {
+        my ($object_stream_num, $object_stream_pos) = @{$object_location};
 
-        $src->read_stream(1) if $src->{' nofilt'};
+        my $object_stream = $self->read_objnum($object_stream_num, 0, %opts);
+        die 'Cannot find the compressed object stream' unless $object_stream;
 
-        my $map = substr($src->{' stream'}, 0, $src->{'First'}->val);
-        my $objects = substr($src->{' stream'}, $src->{'First'}->val);
-        my @mappings = split(/\s+/, $map);
-        my $count = scalar(@mappings);
+        $object_stream->read_stream() if $object_stream->{' nofilt'};
 
-        my $index = $object_location->[1] * 2;
+        # An object stream starts with pairs of integers containing object numbers and
+        # stream offsets relative to the First key
+        my $fh;
+        my $pairs;
+        unless ($object_stream->{' streamfile'}) {
+            $pairs = substr($object_stream->{' stream'}, 0, $object_stream->{'First'}->val);
+        }
+        else {
+            open $fh, '<', $object_stream->{' streamfile'};
+            read($fh, $pairs, $object_stream->{'First'}->val());
+        }
+        my @map = split /\s+/, $pairs;
 
-        if ($mappings[$index] != $num)
-        {
-            die "Objind $num does not exist at index $index";
+        # Find the offset of the object in the stream
+        my $index = $object_stream_pos * 2;
+        die "Objind $num does not exist at index $index" unless $map[$index] == $num;
+        my $start = $map[$index + 1];
+
+        # Unless this is the last object in the stream, its length is determined by the
+        # offset of the next object
+        my $last_object_in_stream = $map[-2];
+        my $length;
+        if ($last_object_in_stream == $num) {
+            if ($object_stream->{' stream'}) {
+                $length = length($object_stream->{' stream'}) - $object_stream->{'First'}->val() - $start;
+            }
+            else {
+                $length = (-s $object_stream->{' streamfile'}) - $object_stream->{'First'}->val() - $start;
+            }
+        }
+        else {
+            my $next_start = $map[$index + 3];
+            $length = $next_start - $start;
         }
 
-        my $start = $mappings[++$index];
-        $index += 2;
-
-        my $length = $index > $count ? length($objects) : $mappings[$index];
-        my $stream = "$num 0 obj" . substr($objects, $start, $length);
+        # Read the object from the stream
+        my $stream = "$num 0 obj ";
+        unless ($object_stream->{' streamfile'}) {
+            $stream .= substr($object_stream->{' stream'}, $object_stream->{'First'}->val() + $start, $length);
+        }
+        else {
+            seek($fh, $object_stream->{'First'}->val() + $start, 0);
+            read($fh, $stream, $length, length($stream));
+            close $fh;
+        }
 
         ($object) = $self->readval($stream, %opts, update => 0);
         return $object;
@@ -818,7 +852,7 @@ sub out_obj {
     # in the hash) (which is super-fast).
     unless (exists $self->{' outlist_cache'}{$obj}) {
         push @{$self->{' outlist'}}, $obj;
-        $self->{' outlist_cache'}{$obj}++;
+        $self->{' outlist_cache'}{$obj} = 1;
     }
     return $obj;
 }
@@ -1203,7 +1237,7 @@ sub readxrtr {
 
     $tdict->{' loc'} = $xpos;
     $tdict->{' xref'} = $xlist;
-    $self->{' maxobj'} = $xmin if $xmin > $self->{' maxobj'};
+    $self->{' maxobj'} = $xmin + 1 if $xmin + 1 > $self->{' maxobj'};
     $tdict->{' prev'} = $self->readxrtr($tdict->{'Prev'}->val)
         if (defined $tdict->{'Prev'} and $tdict->{'Prev'}->val != 0);
     delete $tdict->{' prev'} unless defined $tdict->{' prev'};
