@@ -15,7 +15,7 @@ package PDF::API2::Basic::PDF::Objind;
 use strict;
 use warnings;
 
-our $VERSION = '2.030'; # VERSION
+our $VERSION = '2.030_001'; # TRIAL VERSION
 
 =head1 NAME
 
@@ -154,7 +154,7 @@ Makes sure that the object is fully read in, etc.
 =cut
 
 sub realise {
-    $_[0]->{' realised'} ? $_[0] : $_[0]->{' parent'}->read_obj(@_);
+    $_[0]->{' realised'} ? $_[0] : $_[0]->{' objnum'} ? $_[0]->{' parent'}->read_obj(@_) : $_[0];
 }
 
 =head2 $r->outobjdeep($fh, $pdf)
