@@ -5,7 +5,7 @@ use base 'PDF::API2::Resource::ColorSpace';
 use strict;
 no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '2.029'; # VERSION
+our $VERSION = '2.030_001'; # TRIAL VERSION
 
 use PDF::API2::Basic::PDF::Utils;
 use PDF::API2::Util;
@@ -76,15 +76,6 @@ sub new {
     return($self);
 }
 
-sub new_api {
-    my ($class,$api,@opts)=@_;
-
-    my $obj=$class->new($api->{pdf},pdfkey(),@opts);
-    $obj->{' api'}=$api;
-
-    return($obj);
-}
-
 sub param {
     my $self=shift @_;
     return(@_);
