@@ -3,7 +3,7 @@ package PDF::API2::Resource::UniFont;
 use strict;
 no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '2.030'; # VERSION
+our $VERSION = '2.030_001'; # TRIAL VERSION
 
 use Encode qw(:all);
 
@@ -151,22 +151,6 @@ sub new {
     return($self);
 }
 
-=item $font = PDF::API2::Resource::UniFont->new_api $api, $name, %options
-
-Returns a uni-font object. This method is different from 'new' that
-it needs an PDF::API2-object rather than a Text::PDF::File-object.
-
-=cut
-
-sub new_api {
-    my ($class,$api,@opts)=@_;
-
-    my $obj=$class->new($api->{pdf},@opts);
-    $obj->{api}=$api;
-
-    return($obj);
-}
-
 sub isvirtual { return(1); }
 
 sub fontlist
