@@ -5,7 +5,7 @@ use base 'PDF::API2::Resource';
 use strict;
 use warnings;
 
-our $VERSION = '2.030'; # VERSION
+our $VERSION = '2.030_001'; # TRIAL VERSION
 
 use PDF::API2::Basic::PDF::Utils;
 
@@ -32,9 +32,6 @@ sub new {
     return $self;
 }
 
-# Deprecated (rolled into new)
-sub new_api { my $self = shift(); return $self->new(@_); }
-
 =item $type = $xobject->subtype($type)
 
 Get or set the Subtype of the XObject resource.
