@@ -5,7 +5,7 @@ use base 'PDF::API2::Resource::XObject::Form::Hybrid';
 use strict;
 use warnings;
 
-our $VERSION = '2.029'; # VERSION
+our $VERSION = '2.030_001'; # TRIAL VERSION
 
 use PDF::API2::Util;
 use PDF::API2::Basic::PDF::Utils;
@@ -43,9 +43,6 @@ sub new {
     return $self;
 }
 
-# Deprecated (rolled into new)
-sub new_api { my $self = shift(); return $self->new(@_); }
-
 my %bar_widths = (
      0 => 0,
      1 => 1, 'a' => 1, 'A' => 1,
