@@ -5,7 +5,7 @@ use base 'PDF::API2::Resource::XObject::Image';
 use strict;
 use warnings;
 
-our $VERSION = '2.030'; # VERSION
+our $VERSION = '2.030_001'; # TRIAL VERSION
 
 use IO::File;
 use PDF::API2::Util;
@@ -53,15 +53,6 @@ sub new {
     return $self;
 }
 
-sub new_api {
-    my ($class, $api, @opts) = @_;
-
-    my $obj = $class->new($api->{'pdf'}, @opts);
-    $obj->{' api'} = $api;
-
-    return $obj;
-}
-
 sub read_jpeg {
     my ($self, $fh) = @_;
     my ($buf, $p, $h, $w, $c, $ff, $mark, $len);
