@@ -9,7 +9,7 @@ use base 'PDF::API2::Resource::XObject::Image';
 use strict;
 no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '2.029'; # VERSION
+our $VERSION = '2.030_001'; # TRIAL VERSION
 
 use IO::File;
 use PDF::API2::Util;
@@ -31,15 +31,6 @@ sub new {
     return($self);
 }
 
-sub new_api {
-    my ($class,$api,@opts)=@_;
-
-    my $obj=$class->new($api->{pdf},@opts);
-    $obj->{' api'}=$api;
-
-    return($obj);
-}
-
 # READPPMHEADER
 # taken from Image::PBMLib
 # Copyright by Benjamin Elijah Griffin (28 Feb 2003)
